@@ -30,7 +30,6 @@ import java.io.IOException;
 import java.io.StringWriter;
 import java.lang.reflect.Constructor;
 import java.lang.reflect.Modifier;
-import java.nio.charset.Charset;
 import java.nio.charset.StandardCharsets;
 import java.nio.file.Files;
 import java.nio.file.Paths;
@@ -38,12 +37,11 @@ import java.nio.file.Paths;
 import org.junit.jupiter.api.Test;
 
 /**
- * Unit tests for {@link StringEscapeUtils}.
+ * Tests {@link StringEscapeUtils}.
  *
  * <p>
  * This code has been adapted from Apache Commons Lang 3.5.
  * </p>
- *
  */
 public class StringEscapeUtilsTest {
     private static final String FOO = "foo";
@@ -69,7 +67,7 @@ public class StringEscapeUtilsTest {
 
     private void assertEscapeJava(final String expected, final String original, String message) throws IOException {
         final String converted = StringEscapeUtils.escapeJava(original);
-        message = "escapeJava(String) failed" + (message == null ? "" : (": " + message));
+        message = "escapeJava(String) failed" + (message == null ? "" : ": " + message);
         assertEquals(expected, converted, message);
 
         final StringWriter writer = new StringWriter();
@@ -83,12 +81,11 @@ public class StringEscapeUtilsTest {
 
     private void assertUnescapeJava(final String unescaped, final String original, final String message)
             throws IOException {
-        final String expected = unescaped;
         final String actual = StringEscapeUtils.unescapeJava(original);
 
-        assertEquals(expected, actual, "unescape(String) failed"
-                        + (message == null ? "" : (": " + message))
-                        + ": expected '" + StringEscapeUtils.escapeJava(expected)
+        assertEquals(unescaped, actual, "unescape(String) failed"
+                        + (message == null ? "" : ": " + message)
+                        + ": expected '" + StringEscapeUtils.escapeJava(unescaped)
                         // we escape this so we can see it in the error message
                         + "' actual '" + StringEscapeUtils.escapeJava(actual) + "'");
 
@@ -97,24 +94,16 @@ public class StringEscapeUtilsTest {
         assertEquals(unescaped, writer.toString());
     }
 
-    private void checkCsvEscapeWriter(final String expected, final String value) {
-        try {
-            final StringWriter writer = new StringWriter();
-            StringEscapeUtils.ESCAPE_CSV.translate(value, writer);
-            assertEquals(expected, writer.toString());
-        } catch (final IOException e) {
-            fail("Threw: " + e);
-        }
+    private void checkCsvEscapeWriter(final String expected, final String value) throws IOException {
+        final StringWriter writer = new StringWriter();
+        StringEscapeUtils.ESCAPE_CSV.translate(value, writer);
+        assertEquals(expected, writer.toString());
     }
 
-    private void checkCsvUnescapeWriter(final String expected, final String value) {
-        try {
-            final StringWriter writer = new StringWriter();
-            StringEscapeUtils.UNESCAPE_CSV.translate(value, writer);
-            assertEquals(expected, writer.toString());
-        } catch (final IOException e) {
-            fail("Threw: " + e);
-        }
+    private void checkCsvUnescapeWriter(final String expected, final String value) throws IOException {
+        final StringWriter writer = new StringWriter();
+        StringEscapeUtils.UNESCAPE_CSV.translate(value, writer);
+        assertEquals(expected, writer.toString());
     }
 
     @Test
@@ -136,8 +125,6 @@ public class StringEscapeUtilsTest {
 
 
     // HTML and XML
-    //--------------------------------------------------------------
-
     @Test
     public void testDeleteCharacter() {
       final String deleteString = "Delete: \u007F";
@@ -157,7 +144,7 @@ public class StringEscapeUtilsTest {
     }
 
     @Test
-    public void testEscapeCsvWriter() {
+    public void testEscapeCsvWriter() throws IOException {
         checkCsvEscapeWriter("foo.bar", "foo.bar");
         checkCsvEscapeWriter("\"foo,bar\"", "foo,bar");
         checkCsvEscapeWriter("\"foo\nbar\"", "foo\nbar");
@@ -254,10 +241,10 @@ public void testEscapeEcmaScript() {
         // this is the utf8 representation of the character:
         // COUNTING ROD UNIT DIGIT THREE
         // in Unicode
-        // codepoint: U+1D362
+        // code point: U+1D362
         final byte[] data = {(byte) 0xF0, (byte) 0x9D, (byte) 0x8D, (byte) 0xA2};
 
-        final String original = new String(data, Charset.forName("UTF8"));
+        final String original = new String(data, StandardCharsets.UTF_8);
 
         final String escaped = StringEscapeUtils.escapeHtml4(original);
         assertEquals(original, escaped, "High Unicode should not have been escaped");
@@ -334,14 +321,13 @@ public void testEscapeEcmaScript() {
     public void testEscapeJavaWithSlash() {
         final String input = "String with a slash (/) in it";
 
-        final String expected = input;
         final String actual = StringEscapeUtils.escapeJava(input);
 
         /*
          * In 2.4 StringEscapeUtils.escapeJava(String) escapes '/' characters, which are not a valid character
          * to escape in a Java string.
          */
-        assertEquals(expected, actual);
+        assertEquals(input, actual);
     }
 
     @Test
@@ -428,7 +414,7 @@ public void testEscapeEcmaScript() {
      */
     @Test
     public void testLang708() throws IOException {
-        final byte[] inputBytes = Files.readAllBytes(Paths.get("src/test/resources/stringEscapeUtilsTestData.txt"));
+        final byte[] inputBytes = Files.readAllBytes(Paths.get("src/test/resources/org/apache/commons/text/stringEscapeUtilsTestData.txt"));
         final String input = new String(inputBytes, StandardCharsets.UTF_8);
         final String escaped = StringEscapeUtils.escapeEcmaScript(input);
         // just the end:
@@ -473,7 +459,7 @@ public void testEscapeEcmaScript() {
     }
 
     @Test
-    public void testUnescapeCsvWriter() {
+    public void testUnescapeCsvWriter() throws IOException {
         checkCsvUnescapeWriter("foo.bar", "foo.bar");
         checkCsvUnescapeWriter("foo,bar", "\"foo,bar\"");
         checkCsvUnescapeWriter("foo\nbar", "\"foo\nbar\"");
@@ -503,10 +489,9 @@ public void testEscapeEcmaScript() {
         assertEquals("\u0080\u009F", StringEscapeUtils.unescapeHtml4("&#X80;&#X9F;"), "hex number unescape");
         // Test all Character values:
         for (char i = Character.MIN_VALUE; i < Character.MAX_VALUE; i++) {
-            final Character c1 = i;
-            final Character c2 = (char) (i + 1);
-            final String expected = c1.toString() + c2.toString();
-            final String escapedC1 = "&#x" + Integer.toHexString(c1) + ";";
+            final char c2 = (char) (i + 1);
+            final String expected = Character.toString(i) + Character.toString(c2);
+            final String escapedC1 = "&#x" + Integer.toHexString(i) + ";";
             final String escapedC2 = "&#x" + Integer.toHexString(c2) + ";";
             assertEquals(expected, StringEscapeUtils.unescapeHtml4(escapedC1 + escapedC2),
                     "hex number unescape index " + i);
